@@ -5,8 +5,8 @@ package B::Hooks::EndOfScope;
 BEGIN {
   $B::Hooks::EndOfScope::AUTHORITY = 'cpan:FLORA';
 }
-BEGIN {
-  $B::Hooks::EndOfScope::VERSION = '0.09';
+{
+  $B::Hooks::EndOfScope::VERSION = '0.10';
 }
 # ABSTRACT: Execute code after a scope finished compilation
 
@@ -23,7 +23,14 @@ use Sub::Exporter -setup => {
 {
     my $wiz = Variable::Magic::wizard
         data => sub { [$_[1]] },
-        free => sub { $_->() for @{ $_[1] }; () };
+        free => sub { $_->() for @{ $_[1] }; () },
+        # When someone localise %^H, our magic doesn't want to be copied
+        # down. We want it to be around only for the scope we've initially
+        # attached ourselfs to. Merely having an svt_local callback achieves
+        # this. If anything wants to attach more magic of our kind to a
+        # localised %^H, things will continue to just work as we'll be attached
+        # with a new and empty callback list.
+        local => sub { () };
 
     sub on_scope_end (&) {
         my $cb = shift;
@@ -45,6 +52,8 @@ use Sub::Exporter -setup => {
 __END__
 =pod
 
+=encoding utf-8
+
 =head1 NAME
 
 B::Hooks::EndOfScope - Execute code after a scope finished compilation
@@ -79,11 +88,11 @@ L<Variable::Magic>
 
 =head1 AUTHOR
 
-  Florian Ragwitz <rafl@debian.org>
+Florian Ragwitz <rafl@debian.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2010 by Florian Ragwitz.
+This software is copyright (c) 2012 by Florian Ragwitz.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
